==> mule-service-http-1.12.0-20250910.205153-301-test-sources.jar: org/mule/service/http/impl/functional/server/HttpServerErrorRequestsTestCase.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.service.http.impl.functional.server;

import static org.mule.runtime.api.metadata.MediaType.TEXT;
import static org.mule.runtime.http.api.HttpConstants.HttpStatus.METHOD_NOT_ALLOWED;
import static org.mule.runtime.http.api.HttpConstants.HttpStatus.NOT_FOUND;
import static org.mule.runtime.http.api.HttpConstants.Method.GET;
import static org.mule.runtime.http.api.HttpHeaders.Names.CONTENT_TYPE;

import static java.lang.String.format;
import static java.nio.charset.StandardCharsets.UTF_8;
import static java.util.Collections.singletonList;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.is;

import org.mule.runtime.http.api.HttpConstants.HttpStatus;
import org.mule.runtime.http.api.domain.entity.ByteArrayHttpEntity;
import org.mule.runtime.http.api.domain.message.response.HttpResponse;

import java.net.URI;

import org.apache.commons.io.IOUtils;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.client.methods.HttpRequestBase;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.junit.Before;
import org.junit.Test;

public class HttpServerErrorRequestsTestCase extends AbstractHttpServerTestCase {

  public HttpServerErrorRequestsTestCase(String serviceToLoad) {
    super(serviceToLoad);
  }

  @Before
  public void setUp() throws Exception {
    setUpServer();
    server.addRequestHandler(singletonList(GET.name()), "/test", (requestContext, responseCallback) -> {
      responseCallback.responseReady(HttpResponse.builder().entity(new ByteArrayHttpEntity("Success!".getBytes()))
          .addHeader(CONTENT_TYPE, TEXT.toRfcString())
          .build(), new IgnoreResponseStatusCallback());

    });
  }

  @Override
  protected String getServerName() {
    return "errors-test";
  }

  @Test
  public void methodNotAllowed() throws Exception {
    verifyErrorResponse(new HttpPost(), "test", METHOD_NOT_ALLOWED, "Method not allowed for endpoint: /test");
  }

  @Test
  public void notFound() throws Exception {
    verifyErrorResponse(new HttpGet(), "wat", NOT_FOUND, "No listener for endpoint: /wat");
  }

  private void verifyErrorResponse(HttpRequestBase httpRequest, String path, HttpStatus expectedStatus, String expectedBody)
      throws Exception {
    try (CloseableHttpClient httpClient = HttpClients.createDefault()) {
      httpRequest.setURI(getUri(path));
      try (CloseableHttpResponse response = httpClient.execute(httpRequest)) {
        assertThat(response.getStatusLine().getStatusCode(), is(expectedStatus.getStatusCode()));
        assertThat(response.getStatusLine().getReasonPhrase(), is(expectedStatus.getReasonPhrase()));
        assertThat(response.getFirstHeader(CONTENT_TYPE).getValue(), is(TEXT.toRfcString()));
        assertThat(IOUtils.toString(response.getEntity().getContent(), UTF_8), is(expectedBody));
      }
    }
  }

  private URI getUri(String path) {
    return URI.create(format("http://localhost:%s/%s", port.getValue(), path));
  }

}

==> mule-service-http-1.13.0-20251128.125751-17-test-sources.jar: org/mule/service/http/impl/functional/server/HttpServerErrorRequestsTestCase.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.service.http.impl.functional.server;

import static org.mule.runtime.api.metadata.MediaType.TEXT;
import static org.mule.runtime.http.api.HttpConstants.HttpStatus.METHOD_NOT_ALLOWED;
import static org.mule.runtime.http.api.HttpConstants.HttpStatus.NOT_FOUND;
import static org.mule.runtime.http.api.HttpConstants.Method.GET;
import static org.mule.runtime.http.api.HttpHeaders.Names.CONTENT_TYPE;

import static java.lang.String.format;
import static java.nio.charset.StandardCharsets.UTF_8;
import static java.util.Collections.singletonList;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.is;

import org.mule.runtime.http.api.HttpConstants.HttpStatus;
import org.mule.runtime.http.api.domain.entity.ByteArrayHttpEntity;
import org.mule.runtime.http.api.domain.message.response.HttpResponse;

import java.net.URI;

import org.apache.commons.io.IOUtils;
import org.apache.hc.client5.http.classic.methods.HttpGet;
import org.apache.hc.client5.http.classic.methods.HttpPost;
import org.apache.hc.client5.http.classic.methods.HttpUriRequestBase;
import org.apache.hc.client5.http.impl.classic.CloseableHttpClient;
import org.apache.hc.client5.http.impl.classic.CloseableHttpResponse;
import org.apache.hc.client5.http.impl.classic.HttpClients;
import org.junit.Before;
import org.junit.Test;

public class HttpServerErrorRequestsTestCase extends AbstractHttpServerTestCase {

  public HttpServerErrorRequestsTestCase(String serviceToLoad) {
    super(serviceToLoad);
  }

  @Before
  public void setUp() throws Exception {
    setUpServer();
    server.addRequestHandler(singletonList(GET.name()), "/test", (requestContext, responseCallback) -> {
      responseCallback.responseReady(HttpResponse.builder().entity(new ByteArrayHttpEntity("Success!".getBytes()))
          .addHeader(CONTENT_TYPE, TEXT.toRfcString())
          .build(), new IgnoreResponseStatusCallback());

    });
  }

  @Override
  protected String getServerName() {
    return "errors-test";
  }

  @Test
  public void methodNotAllowed() throws Exception {
    verifyErrorResponse(new HttpPost(""), "test", METHOD_NOT_ALLOWED, "Method not allowed for endpoint: /test");
  }

  @Test
  public void notFound() throws Exception {
    verifyErrorResponse(new HttpGet(""), "wat", NOT_FOUND, "No listener for endpoint: /wat");
  }

  private void verifyErrorResponse(HttpUriRequestBase httpRequest, String path, HttpStatus expectedStatus, String expectedBody)
      throws Exception {
    try (CloseableHttpClient httpClient = HttpClients.createDefault()) {
      httpRequest.setUri(getUri(path));
      try (CloseableHttpResponse response = httpClient.execute(httpRequest)) {
        assertThat(response.getCode(), is(expectedStatus.getStatusCode()));
        assertThat(response.getReasonPhrase(), is(expectedStatus.getReasonPhrase()));
        assertThat(response.getFirstHeader(CONTENT_TYPE).getValue(), is(TEXT.toRfcString()));
        assertThat(IOUtils.toString(response.getEntity().getContent(), UTF_8), is(expectedBody));
      }
    }
  }

  private URI getUri(String path) {
    return URI.create(format("http://localhost:%s/%s", port.getValue(), path));
  }

}
